using Autofac;
using FitConnect;
using FitConnect.Encryption;
using FitConnect.Models;
using Microsoft.Extensions.Logging;
using MockContainer;

namespace E2ETest;

public abstract class EndToEndTestBase {
    private Sender _sender;
    private Subscriber _subscriber;

    [OneTimeSetUp]
    public void Setup() {
        var container = MockContainer.Container.Create();
        var settings = container.Resolve<MockSettings>();

        var logger = LoggerFactory.Create(
            builder => {
                builder.AddSimpleConsole();
                builder.SetMinimumLevel(LogLevel.Trace);
            }).CreateLogger("E2E Test");


        _sender = Client.GetSender(FitConnectEnvironment.Development,
            settings.SenderClientId, settings.SenderClientSecret,
            logger);
        _subscriber = Client.GetSubscriber(FitConnectEnvironment.Development,
            settings.SenderClientId, settings.SenderClientSecret,
            settings.PrivateKeyDecryption,
            settings.PrivateKeySigning,
            settings.PublicKeyEncryption,
            settings.PublicKeySignatureVerification,
            logger
        );
    }
}

public class StraightForwardTest : EndToEndTestBase {
    [Order(10)]
    [Test]
    public void Test1() {
        Assert.Pass();
    }
}

public class RejectSubmissionTest : EndToEndTestBase {
}
